beamprofiler.iso.characterizing\_parameters
===========================================

.. automodule:: beamprofiler.iso.characterizing_parameters

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      beam_aspect_ratio
      beam_center
      beam_uniformity
      beam_width
      clip_level_average_power_density
      clip_level_irradiation_area
      edge_steepness
      flatness_factor
      fractional_power
      plateau_uniformity
   
   

   
   
   

   
   
   



